durationtools.assignable_rational_to_dot_count
==============================================

.. autofunction:: abjad.tools.durationtools.assignable_rational_to_dot_count.assignable_rational_to_dot_count
